# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'RegionResult',
    'AwaitableRegionResult',
    'region',
]

@pulumi.output_type
class RegionResult:
    """
    A collection of values returned by Region.
    """
    def __init__(__self__, id=None, regions=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def regions(self) -> Sequence['outputs.RegionRegionResult']:
        return pulumi.get(self, "regions")


class AwaitableRegionResult(RegionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return RegionResult(
            id=self.id,
            regions=self.regions)


def region(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableRegionResult:
    """
    ## Example Usage

    ```python
    import pulumi
    import pulumi_materialize as materialize

    all = materialize.region()
    pulumi.export("region", all)
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('materialize:index/region:Region', __args__, opts=opts, typ=RegionResult).value

    return AwaitableRegionResult(
        id=pulumi.get(__ret__, 'id'),
        regions=pulumi.get(__ret__, 'regions'))
